<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:output method="html"/>
	<xsl:variable name="HTMLPresentation">
		<!-- Version Details -->
		<CensusDetail type="School Census 2022-2023"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2023.1.4" released="2022-12-23" author="Andy Naylor" comment="Added new rule 3131.  Rule 4016 changed from Error to Query"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2023.1.3" released="2022-12-16" author="Andy Naylor" comment="Minor updates to rules 2397 and 2398 and Table 15 in School Summary"/>
			<Version number="2023.1.2" released="2022-11-16" author="Andy Naylor" comment="Beta version for Spring 23."/>
			<Version number="2023.1.1" released="2022-09-13" author="Andy Naylor" comment="Rules 1886, 2876 Updated to use correct fields.  Tables 16, 17 in school summary had date comparison corrected."/>
			<Version number="2023.0.1" released="2022-06-01" author="Andy Naylor" comment="rolled over from summer census 2022 and updated for Autumn 22"/>
		</VersionHistory>
		<!-- End of Version Details -->
	</xsl:variable>
	<xsl:template match="/">
		<html>
			<head>
				<title>School Census Validation report</title>
			</head>
			<!--<body bgcolor="#CCFFFF">-->
			<body bgcolor="#FFFFFF">
				<b>
					<xsl:variable name="Term">
						<xsl:choose>
							<xsl:when test=" /ProcessingResults/ValidationResults/Header/CollectionDetails/Term='AUT' ">
								<xsl:value-of select=" ' Autumn' "/>
							</xsl:when>
							<xsl:when test=" /ProcessingResults/ValidationResults/Header/CollectionDetails/Term='SPR' ">
								<xsl:value-of select=" ' Spring' "/>
							</xsl:when>
							<xsl:when test=" /ProcessingResults/ValidationResults/Header/CollectionDetails/Term='SUM' ">
								<xsl:value-of select=" ' Summer' "/>
							</xsl:when>
						</xsl:choose>
					</xsl:variable>
					<h1>
						<xsl:value-of select=" /ProcessingResults/ValidationResults/Header/CollectionDetails/Year"/>
						<xsl:value-of select=" $Term"/>
						School Census Validation Report <font size="3" color="#027087">
							<br/>  (Version <xsl:value-of select="ProcessingResults/XSLTVersion"/>)</font>
					</h1>
					<p/>
					<font color="#000066">
						<h3>
							<xsl:value-of select="/ProcessingResults/ValidationResults/Summary/SchoolName"/>
							<br/>
							<xsl:value-of select="concat('(',/ProcessingResults/ValidationResults/Header/Source/LEA, '/', /ProcessingResults/ValidationResults/Header/Source/Estab, ')')"/>
							<br/>
							<br/>
							<xsl:value-of select="concat('School Phase: ', /ProcessingResults/ValidationResults/Summary/SchoolPhase)"/>
							<br/>
							<xsl:value-of select="concat('Census Term: ',  /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)"/>
							<br/>
							<br/>
							<!--<xsl:value-of select="concat('Pupils on Roll: ',$PupilOnRollCount, ', Pupils no longer on Roll: ',$PupilNoLongerOnRollCount, ', Classes: ', count(/Message/School/Classes/Class))"/>-->
							<xsl:value-of select="concat('Pupils on roll: ',/ProcessingResults/ValidationResults/Summary/PupilsOnRoll)"/>
							<br/>
							<xsl:value-of select="concat('Pupils no longer on roll: ',/ProcessingResults/ValidationResults/Summary/PupilsNoLongerOnRoll)"/>
							<br/>
							<xsl:value-of select="concat('Classes: ', /ProcessingResults/ValidationResults/Summary/Classes)"/>
						</h3>
						<xsl:if test=" /ProcessingResults/ValidationResults/Summary/SchoolPhase ='Unknown' ">
							<h2>The School Phase is shown as "Unknown" above because one or more key items - Phase, Governance or Intake - is missing. These items are used to determine how your data is validated.  Please correct these and re-output the school census data from your system.</h2>
						</xsl:if>
					</font>
				</b>
				<xsl:variable name="phase" select="/ProcessingResults/ValidationResults/Summary/SchoolPhase"/>
				<xsl:variable name="term" select="/ProcessingResults/ValidationResults/Header/CollectionDetails/Term"/>
				<xsl:variable name="nErrors" select="count(/ProcessingResults/Errors/Error[Type='Error' and contains(Term, $term) and contains(Phase, $phase)])"/>
				<xsl:variable name="nQueries" select="count(/ProcessingResults/Errors/Error[Type='Query' and contains(Term, $term) and contains(Phase, $phase)])"/>
				<font color="#990000">
					<b>There are <xsl:value-of select="$nErrors"/>  errors and <xsl:value-of select="$nQueries"/> queries.<br/>
					</b>
				</font>
				<p/>
				<xsl:if test="$nErrors + $nQueries != 0">
					<table border="0" style="font-size: x-small; font-family: Arial, Helvetica, sans-serif">
						<tbody>
							<th bgcolor="#330099" style="color: #ffffff">Type</th>
							<th bgcolor="#330099" style="color: #ffffff">Sequence</th>
							<th bgcolor="#330099" style="color: #ffffff" align="left">Data (where applicable): Message</th>
							<xsl:for-each select="/ProcessingResults/Errors/Error[contains(Term, $term) and contains(Phase, $phase)]">
								<!--<xsl:for-each select="/ProcessingResults/Errors/Error"> -->
								<xsl:sort select="Type"/>
								<!-- Amended IS 2005-02-15 Added translate so that query numbers sorted correctly -->
								<xsl:sort select="translate(Sequence,'Q','')" data-type="number"/>
								<tr bgcolor="#99ccff">
									<td>
										<xsl:value-of select="Type"/>
									</td>
									<td>
										<xsl:value-of select="Sequence"/>
									</td>
									<td>
										<xsl:if test="Location and not(Location='')">
											<xsl:value-of select="concat(Location, ' : ')"/>
										</xsl:if>
										<xsl:value-of select="Message"/>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
