<?xml version="1.0" encoding="utf-8" ?> 
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:output method="xml" indent="yes"/>
<xsl:variable name="XMLPresentation">
		<!-- Version Details -->
		<CensusDetail type="School Census 2022-2023"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2023.1.4" released="2022-12-23" author="Andy Naylor" comment="Added new rule 3131.  Rule 4016 changed from Error to Query"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2023.1.3" released="2022-12-16" author="Andy Naylor" comment="Minor updates to rules 2397 and 2398 and Table 15 in School Summary"/>
			<Version number="2023.1.2" released="2022-11-16" author="Andy Naylor" comment="Beta version for Spring 23."/>
			<Version number="2023.1.1" released="2022-09-13" author="Andy Naylor" comment="Rules 1886, 2876 Updated to use correct fields.  Tables 16, 17 in school summary had date comparison corrected."/>
			<Version number="2023.0.1" released="2022-06-01" author="Andy Naylor" comment="rolled over from summer census 2022 and updated for Autumn 22"/>
		</VersionHistory>
		<!-- End of Version Details -->
</xsl:variable>
	<xsl:template match="/">
		<ValidationResults>
			<xsl:copy-of select="ProcessingResults/XSLTVersion"/>
			<xsl:copy-of select="/ProcessingResults/ValidationResults/Header"/>
			<Summary>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/SchoolName"/>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/SchoolPhase"/>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/PupilsOnRoll"/>	
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/PupilsNoLongerOnRoll"/>									
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/Classes"/>					
				<Errors>
					<xsl:value-of select="count(/ProcessingResults/Errors/Error[Type='Error' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term) and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)])"/>				
				</Errors>
				<Queries>
					<xsl:value-of select="count(/ProcessingResults/Errors/Error[Type='Query' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)])"/>
				</Queries>				
			</Summary>
			<xsl:copy-of select="/ProcessingResults/ValidationResults/ReferenceDates"/>			
			<Errors>
				<xsl:for-each select="/ProcessingResults/Errors/Error[Type='Error' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)]">
					<xsl:sort select="Sequence" data-type="number"/>
					<xsl:call-template name="ErrorOut"/>
				</xsl:for-each>
			</Errors>
			<Queries>
				<xsl:for-each select="/ProcessingResults/Errors/Error[Type='Query' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)]">
					<xsl:sort select="translate(Sequence,'Q','')" data-type="number"/>
					<xsl:call-template name="QueryOut"/>
				</xsl:for-each>				
			</Queries>		
		</ValidationResults>
	</xsl:template>

	<xsl:template name="ErrorOut">
		<xsl:element name="Error">
			<xsl:element name="Sequence">
				<xsl:value-of select="./Sequence"/>
			</xsl:element>
			<xsl:element name="Location">
				<xsl:value-of select="./Location"/>
			</xsl:element>
			<xsl:element name="ErrorMessage">
				<xsl:value-of select="./Message"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template name="QueryOut">
		<xsl:element name="Query">
			<xsl:element name="Sequence">
				<xsl:value-of select="./Sequence"/>
			</xsl:element>
			<xsl:element name="Location">
				<xsl:value-of select="./Location"/>
			</xsl:element>
			<xsl:element name="ErrorMessage">
				<xsl:value-of select="./Message"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet>
